@@ -100,13 +100,19 @@ class SchemaClient:
             else raise_exception(TypeError("Expected not None"))
         )
 
-    def delete(self, schema: SchemaId, cascade: bool) -> Cmd[None]:
+    def _delete(self, schema: SchemaId, cascade: bool) -> Cmd[None]:
         opt = " CASCADE" if cascade else ""
         stm: str = "DROP SCHEMA {schema_name}" + opt
         return self._db_client.execute(
             dynamic_query(stm, FrozenDict({"schema_name": schema.name})), None
         )
 
+    def delete(self, schema: SchemaId) -> Cmd[None]:
+        return self._delete(schema, False)
+
+    def delete_cascade(self, schema: SchemaId) -> Cmd[None]:
+        return self._delete(schema, True)
+
     def rename(self, old: SchemaId, new: SchemaId) -> Cmd[None]:
         stm = "ALTER SCHEMA {from_schema} RENAME TO {to_schema}"
         return self._db_client.execute(
@@ -131,6 +137,21 @@ class SchemaClient:
             dynamic_query(stm, FrozenDict({"schema": schema.name})), None
         )
 
+    def _recreate(self, schema: SchemaId, cascade: bool) -> Cmd[None]:
+        return self.exist(schema).bind(
+            lambda b: self._delete(schema, cascade).bind(
+                lambda _: self.create(schema)
+            )
+            if b
+            else Cmd.from_cmd(lambda: None)
+        )
+
+    def recreate(self, schema: SchemaId) -> Cmd[None]:
+        return self._recreate(schema, False)
+
+    def recreate_cascade(self, schema: SchemaId) -> Cmd[None]:
+        return self._recreate(schema, True)
+
     def set_policy(self, schema: SchemaId, policy: SchemaPolicy) -> Cmd[None]:
         stm = "ALTER SCHEMA {schema} OWNER TO {owner}"
         stm2 = (
