@@ -18,7 +18,7 @@ from redshift_client.column import (
 from redshift_client.data_type.decode import (
     decode_type,
 )
-from redshift_client.sql_client.core import (
+from redshift_client.sql_client import (
     PrimitiveVal,
 )
 from typing import (
